@@ -44,9 +44,7 @@ PS_Config::PS_Config()
 	CPU_IDLE_LIMIT = 25;
 	MAX_CPUS_ONLINE = 0;
 	CPU_IDLE_TIMEOUT = 10;
-	CPU_HIGH_LIMIT = 80;
-	JUMP_CPU_FREQ_MAX_LIMIT = 50;
-	CPUFREQ_HYSTERESIS = 5;
+	CPUFREQ_DYNAMIC_PERFORMANCE = 50;
 	CONSIDER_NICE = 0;
 	POLL_INTERVAL = 333;
 	CPUFREQ_ENABLED = true;
@@ -59,10 +57,6 @@ PS_Config::PS_Config()
 
 	DISPLAY_BRIGHTNESS = -1;	// -1 == off / don't care
 
-	USER_STANDBY_DISABLED = 1;
-	USER_SUSPEND2DISK_DISABLED = 0;
-	USER_SUSPEND2RAM_DISABLED = 0;
-	DPM_ENABLED = 1;
 	POWER_BUTTON_DELAY = 0;
 
 	ALLOW_THROTTLING = false;
@@ -190,7 +184,6 @@ void PS_Config::assignConfigEntries()
 	std::string s, t;
 	int i;
 
-	CPU_HIGH_LIMIT = checkValue(CPU_HIGH_LIMIT, "CPU_HIGH_LIMIT", 0, 100);
 	BAT_CRIT_LIMIT = checkValue(BAT_CRIT_LIMIT, "BATTERY_CRITICAL", 0, 100);
 	BAT_LOW_LIMIT = checkValue(BAT_LOW_LIMIT, "BATTERY_LOW", BAT_CRIT_LIMIT, 100);
 	BAT_WARN_LIMIT = checkValue(BAT_WARN_LIMIT, "BATTERY_WARNING", BAT_LOW_LIMIT, 100);
@@ -204,17 +197,10 @@ void PS_Config::assignConfigEntries()
 
 	MAX_CPUS_ONLINE = checkValue(MAX_CPUS_ONLINE, "MAX_CPUS_ONLINE", 0, 100);
 
-	USER_SUSPEND2DISK_DISABLED = checkYes(USER_SUSPEND2DISK_DISABLED, "DISABLE_USER_SUSPEND2DISK");
-	USER_SUSPEND2RAM_DISABLED = checkYes(USER_SUSPEND2RAM_DISABLED, "DISABLE_USER_SUSPEND2RAM");
-	USER_STANDBY_DISABLED = checkYes(USER_STANDBY_DISABLED, "DISABLE_USER_STANDBY");
-
-	DPM_ENABLED = checkYes(DPM_ENABLED, "ENABLE_DPM");
-
 	CONSIDER_NICE = checkYes(CONSIDER_NICE, "CONSIDER_NICE");
 
-	JUMP_CPU_FREQ_MAX_LIMIT = checkValue(JUMP_CPU_FREQ_MAX_LIMIT, "JUMP_CPU_FREQ_MAX_LIMIT", 0, 99);
-
-	CPUFREQ_HYSTERESIS = checkValue(CPUFREQ_HYSTERESIS, "CPU_HYSTERESIS", 0, 99);
+	CPUFREQ_DYNAMIC_PERFORMANCE = checkValue(CPUFREQ_DYNAMIC_PERFORMANCE,
+						 "CPUFREQ_DYNAMIC_PERFORMANCE", 1, 100);
 
 	s = data["ENABLE_THERMAL_MANAGEMENT"];
 	if (s == "" || s == "kernel_passive") {
@@ -305,24 +291,6 @@ void PS_Config::assignConfigEntries()
 	else
 		DISPLAY_BRIGHTNESS = checkValue(DISPLAY_BRIGHTNESS, "DISPLAY_BRIGHTNESS", 0);
 
-
-	/* map class names used in config file to our internal device
-	 * classes for runtime powermanagement */
-	list< string > classes;
-	splitLine(data["DPM_DEVICES"], classes);
-
-	for (list< string >::iterator it = classes.begin();
-	     it != classes.end(); ++it) {
-
-		int i = 0;
-		while (i != DPM_CLASS_MAX) {
-			if ((*it) == DPM_CLASS_NAMES[i]) {
-				dpmClasses.push_back((DPM_DEVICE_CLASS)i);
-			}
-			i++;
-		}
-	}
-
 	for (int x = 0; x < MAX_THERMAL_ZONES; x++) {
 		if (thermal_zones[x].present == 0)
 			continue;
