@@ -27,9 +27,10 @@
 
 #include <map>
 #include <string>
+#include <list>
+
 #include "powerlib.h"
 #include "event.h"
-#include "device.h"
 
 #ifdef CREATE_DEBUG_OUTPUT
 #include <sstream>
@@ -42,15 +43,10 @@
 
 enum CPUFREQ_MODE { _DYNAMIC, _PERFORMANCE, _POWERSAVE };
 
-/** @brief the cpufreq control mode
- *
- * start with 1 to be used as bitmask
- */
-enum CPUFREQ_CONTROL_MODE { CPUFREQ_USERSPACE = 1, CPUFREQ_KERNEL };
+enum CPUFREQ_CONTROL_MODE { CPUFREQ_NONE, CPUFREQ_USERSPACE, CPUFREQ_KERNEL };
 
 enum THERMAL_MANAGEMENT_DELIGATION { OFF, KERNEL, KERNEL_PASSIVE };
 
-class Event;
 class GeneralConfig;
 
 using namespace std;
@@ -64,7 +60,7 @@ public:
 	/** @brief destructor */
 	virtual ~ PS_Config();
 	
-	virtual Event & getEvent(const string &event_name);
+	virtual class Event & getEvent(const string &event_name);
 
 	virtual int readConfigFile(const std::string & file = "");
 
@@ -93,10 +89,6 @@ public:
 	/** @brief cpufreq should be controlled by userspace or kernel */
 	CPUFREQ_CONTROL_MODE CPUFREQ_CONTROL;
 	
-	/** @brief cpu load percentage at which we increase the cpu
-	 * speed */
-	int CPU_HIGH_LIMIT;
-
 	/** what't that. I can't find word deligation */
 	THERMAL_MANAGEMENT_DELIGATION ENABLE_THERMAL_MANAGEMENT;
 
@@ -121,15 +113,6 @@ public:
 	 * too? */
 	int CONSIDER_NICE;
 
-	/** @brief if suspend to disk is disabled */
-	int USER_SUSPEND2DISK_DISABLED;
-
-	/** @brief if suspend to ram is disabled */
-	int USER_SUSPEND2RAM_DISABLED;
-
-	/** @brief if standby is disabled */
-	int USER_STANDBY_DISABLED;
-
 	/** @brief absolute brightness level (depends on driver) or:
 		   -1 ignore -2 low -3 medium -4 high */
 	int DISPLAY_BRIGHTNESS;
@@ -149,24 +132,9 @@ public:
 	 * percent value */
 	int BAT_CRIT_LIMIT;
 
-	/** @brief percent on which the cpu frequency is set immediately
-	 * to maximum
-	 *
-	 * Set the CPU load difference limit for which the highest
-	 * available frequency is set immediately (e.g. if set to 60, it
-	 * switches to full speed if the CPU load jumps from 5% to 66% or
-	 * higher instead of ramping up through all available
-	 * frequencies). Disable the direct triggering of the highest
-	 * frequency by setting a value of 0.
-	 */
-	int JUMP_CPU_FREQ_MAX_LIMIT;
-
 	/** @brief whether cpufrequency scaling is enabled */
 	bool CPUFREQ_ENABLED;
 
-	/** @brief if dpm is enabled */
-	bool DPM_ENABLED;
-
 	/** 
 	 * The hysteresis for calculating the CPU load limit to switch to
 	 * the next lover CPU frequency. Increasing this value lowers the
@@ -176,7 +144,7 @@ public:
 	 * (e.g. when watching a movie).  5 is default, you should not set
 	 * it higher than 40.  Zero is not allowed.
 	 */
-	int CPUFREQ_HYSTERESIS;
+	int CPUFREQ_DYNAMIC_PERFORMANCE;
 
 	/** @brief filename of the battery scheme without the leading scheme_*
 	 *
@@ -208,11 +176,6 @@ public:
 	/** Actions for events as specified in events config file
 	   or maybe specialised in a scheme configuration */
 	 map < string, Event > eventMap;
-
-	 /** list containing device classes @ref DPM_DEVICE_CLASS which
-	  * should get suspended */
-	 std::list < DPM_DEVICE_CLASS > dpmClasses;
-
 	/********** end of configuration variables **********/
 
 private:
