@@ -1,7 +1,15 @@
 #include "cpu.h"
-#include "cpufreq_interface.h"
+#include "powerlib.h"
 
 #include <sstream>
+#include <errno.h>
+#include <stdarg.h>
+#include <stdlib.h>
+#include <string.h>
+
+#define SYSFS_FILES "/sys/devices/system/cpu/"
+
+using namespace std;
 
 CPU::CPU(int id) : _cpu_base(id)
 {
@@ -16,7 +24,7 @@ int CPU::enable()
 		return 0;
 
 	pDebug(DBG_INFO, "Trying to enable CPU %d", _cpu_base);
-	if (!CPUFreq_Interface::write_line(ONLINE_FILE.c_str(), "1")) {
+	if (!write_line(ONLINE_FILE.c_str(), "1")) {
 		pDebug(DBG_DEBUG, "Unable to open file: %s\n", ONLINE_FILE.c_str());
 		return -1;
 	}
@@ -43,7 +51,7 @@ int CPU::disable()
 	}
 	
 	pDebug(DBG_INFO, "Trying to disable CPU %d", _cpu_base);
-	if (!CPUFreq_Interface::write_line(ONLINE_FILE.c_str(), "0")) {
+	if (!write_line(ONLINE_FILE.c_str(), "0")) {
 		pDebug(DBG_DEBUG, "Unable to open file: %s\n",
 		       ONLINE_FILE.c_str());
 		return -1;
@@ -66,7 +74,7 @@ bool CPU::online()
 
 	char online_str[2];
 
-	if (!CPUFreq_Interface::read_line(ONLINE_FILE.c_str(), online_str, 2)) {
+	if (!read_line(ONLINE_FILE.c_str(), online_str, 2)) {
 		pDebug(DBG_DEBUG, "Unable to open file: %s\n", ONLINE_FILE.c_str());
 		return false;
 	}
@@ -103,3 +111,39 @@ int CPU::enableAll()
 	return i;
 }
 
+
+bool CPU::read_line(const char *filename, char *line, unsigned len)
+{
+	FILE *fp = fopen(filename, "r");
+	if (!fp) {
+		pDebug(DBG_ERR, "Could not open '%s': %s", filename, strerror(errno));
+		return false;
+	}
+	if ((!fgets(line, len, fp))) {
+		pDebug(DBG_ERR, "Could not read from '%s': %s", filename, strerror(errno));
+		fclose(fp);
+		return false;
+	}
+	fclose(fp);
+	return true;
+}
+
+bool CPU::write_line(const char *filename, const char *fmt, ...)
+{
+	FILE *fp = fopen(filename, "w+");
+	if (!fp) {
+		pDebug(DBG_WARN, "Could not open file for writing: %s; %s", filename, strerror(errno));
+		return false;
+	}
+	va_list ap;
+	va_start(ap, fmt);	// get variable argument list passed
+	if (vfprintf(fp, fmt, ap) < 0) {
+		pDebug(DBG_WARN, "Could not write to file: %s", filename);
+		fclose(fp);
+		return false;
+	}
+	va_end(ap);
+	fclose(fp);
+	return true;
+}
+
