@@ -54,6 +54,26 @@ public:
 	 */
 	bool hotpluggable();
 
+	/** @brief read a line from a file
+	 *
+	 * @param filename the filename to read from
+	 * @param line char pointer to store the read line
+	 * @param len chars to read
+	 *
+	 * @return false on error
+	 */
+	bool read_line(const char *filename, char *line, unsigned len);
+
+	/** @brief write a line to a file
+	 *
+	 * @param filename the filename to read from
+	 * @param fmt format to write
+	 * @param ... variable argument list to write
+	 *
+	 * @return false on error
+	 */
+	bool write_line(const char *filename, const char *fmt, ...);
+
 protected:
 	/** @brief Stores which CPU this object corresponds to */
 	int _cpu_base;
