@@ -27,8 +27,14 @@
 #include "pm_interface.h"
 #include "globals.h"
 #include "main_loop.h"
-#include "clientConnection.h"
-#include "powersave_hal.h"
+#include "powerlib.h"
+
+#include <string>
+
+using namespace std;
+
+#include <liblazy.h>
+#include <string.h>
 
 DBusConnection* DBus_Server::_connection = NULL;
 
@@ -95,6 +101,8 @@ DBusHandlerResult DBus_Server::filter_function(DBusConnection * conn, DBusMessag
 	*/
 	if (dbus_message_is_signal(msg, DBUS_INTERFACE_LOCAL, "Disconnected")) {
 		pDebug(DBG_ERR, "DBus daemon disconnected. Trying to reconnect...");
+		dbus_connection_unref(_connection);
+		_connection = NULL;
 		// only way I see for now to get this information
 		Powersave::Globals::main_loop->addCallback(3000, (GSourceFunc) DBus_Server::dbus_reconnect);
 		return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
@@ -102,7 +110,10 @@ DBusHandlerResult DBus_Server::filter_function(DBusConnection * conn, DBusMessag
 
 	int type = dbus_message_get_type(msg);
 	if (type == DBUS_MESSAGE_TYPE_ERROR) {
-		pDebug(DBG_ERR, "Received error message: %s", dbus_message_get_error_name(msg));
+		char *error;
+		dbus_message_get_args(msg, NULL, DBUS_TYPE_STRING, &error, DBUS_TYPE_INVALID);
+		pDebug(DBG_ERR, "Received error message: %s, %s", dbus_message_get_error_name(msg),
+		       error);
 		return DBUS_HANDLER_RESULT_HANDLED;
 	}
 	/* Have to use const char* instead of string here.
@@ -114,8 +125,6 @@ DBusHandlerResult DBus_Server::filter_function(DBusConnection * conn, DBusMessag
 		return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 	}
 	const string interface = t;
-	/* We only handle messages which want a reply */
-	int reply_wanted = !dbus_message_get_no_reply(msg);
 	// We do not compare the object path, I see no need for ...
 	//          && strcmp(dbus_message_get_path(msg), DBUS_MESSAGE_BUS_PATH) == 0) {
 
@@ -130,51 +139,40 @@ DBusHandlerResult DBus_Server::filter_function(DBusConnection * conn, DBusMessag
 	int reply_error_id;
 
 	DBusMessage *reply;
+
+	string msg_member = dbus_message_get_member(msg);
+	string sender = dbus_message_get_sender(msg);
+
+	pDebug(DBG_INFO, "Received msg: '%s' from interface: %s", msg_member.c_str(),
+	       interface.c_str());
+	pDebug(DBG_DEBUG, "Obj.path '%s' from '%s'", dbus_message_get_path(msg), sender.c_str());
+
+
 	/** @brief checking of interfaces is done here in filter function
 	 *         checking for the right member, message contents, etc. must
 	 *         be done in pm->handleDBusRequest(..)
 	 *         Create the Message here, we must send a reply (sendReply(),
 	 *         there the memory for the reply will be freed again.
 	 */
-	if (interface == PS_DBUS_MANAGER_INTERFACE) {
-		if (type != DBUS_MESSAGE_TYPE_METHOD_CALL || !reply_wanted) {
-			pDebug(DBG_ERR, "Invalid msg type sent to manager interface");
-		} else {
-			reply = dbus_message_new_method_return(msg);
-			pDebug(DBG_DIAG, "Method sent to manager interface");
-			reply_error_id = pm->handleDBusRequest(msg, reply, MANAGER_MESSAGE);
-			sendReply(reply, reply_error_id);
-		}
-		ret = DBUS_HANDLER_RESULT_HANDLED;
-	} else if (interface == PS_DBUS_SCRIPTS_INTERFACE){
-		if (type != DBUS_MESSAGE_TYPE_METHOD_CALL || !reply_wanted){
+	if (interface == PS_DBUS_SCRIPTS_INTERFACE){
+		if (type != DBUS_MESSAGE_TYPE_METHOD_CALL){
 			pDebug (DBG_ERR, "Invalid msg type sent to Scripts interface");
 		}
 		else{
 			reply = dbus_message_new_method_return(msg);
 			pDebug (DBG_DIAG, "Method sent to Scripts interface");
-			reply_error_id = pm->handleDBusRequest(msg, reply, SCRIPTS_MESSAGE);
+			reply_error_id = pm->handleScriptsMessage(msg, msg_member);
 			sendReply(reply, reply_error_id);
 		}
 		ret = DBUS_HANDLER_RESULT_HANDLED;
-	} else if (interface == PS_DBUS_REQUEST_INTERFACE) {
-		if (type != DBUS_MESSAGE_TYPE_METHOD_CALL || !reply_wanted) {
-			pDebug(DBG_ERR, "Invalid msg sent to request interface");
-		} else {
-			reply = dbus_message_new_method_return(msg);
-			pDebug(DBG_INFO, "Method sent to request interface");
-			reply_error_id = pm->handleDBusRequest(msg, reply, REQUEST_MESSAGE);
-			sendReply(reply, reply_error_id);
-		}
-		ret = DBUS_HANDLER_RESULT_HANDLED;
-	} else if (interface == PS_DBUS_ACTION_INTERFACE
-		   || interface == PS_DBUS_ADMIN_INTERFACE) {
-		if (type != DBUS_MESSAGE_TYPE_METHOD_CALL || !reply_wanted) {
+	//action interface kept for compatibility
+	} else if (interface == PS_DBUS_INTERFACE || interface == "com.novell.powersave.action") {
+		if (type != DBUS_MESSAGE_TYPE_METHOD_CALL) {
 			pDebug(DBG_ERR, "Invalid msg sent to action interface");
 		} else {
 			reply = dbus_message_new_method_return(msg);
 			pDebug(DBG_INFO, "Method sent to action interface");
-			reply_error_id = pm->handleDBusRequest(msg, reply, ACTION_MESSAGE);
+			reply_error_id = pm->handleDBusMessage(msg, reply, msg_member);
 			sendReply(reply, reply_error_id);
 		}
 		ret = DBUS_HANDLER_RESULT_HANDLED;
@@ -196,8 +194,8 @@ DBusHandlerResult DBus_Server::filter_function(DBusConnection * conn, DBusMessag
 
 				/* get the second (the old owner) and the third (the new owner)
 				   string of the message (first string: affected owner) */
-				if (!dbusGetMessageString(msg, &old_owner, 0)
-				    && !dbusGetMessageString(msg, &new_owner, 2)
+				if (!liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_STRING, &old_owner, 0)
+				    && !liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_STRING, &new_owner, 2)
 				    && old_owner != NULL && new_owner != NULL) {
 					/* if the new owner is "" the client broke away -> remove
 					   from client list */
@@ -206,37 +204,19 @@ DBusHandlerResult DBus_Server::filter_function(DBusConnection * conn, DBusMessag
 						if (!strcmp(old_owner, "org.freedesktop.Hal")) {
 							pDebug(DBG_WARN, "Hal service stopped. "
 							       "Battery information no longer available");
-							ps_hal_free();
-						} else {
-							pm->_cC->checkClientRemoval(old_owner);
 						}
 					}
 				}
 			}
 		}
-	} else if (interface == DBUS_HAL_MANAGER_INTERFACE) {
-		string msg_member = dbus_message_get_member(msg);
-		char *udi;
-		if (!dbusGetMessageString(msg, &udi, 0)) {
-			if (msg_member == "DeviceRemoved") {
-				pm->checkDevice(udi, false);
-			}
-			else if (msg_member == "DeviceAdded") {
-				pm->checkDevice(udi, true);
-			}
-		}
-		else {
-			pDebug(DBG_WARN, "Got signal %s from hal, but no string argument",
-			       msg_member.c_str());
-		}
 	} else if (interface == DBUS_HAL_DEVICE_INTERFACE) {
  		string msg_member = dbus_message_get_member(msg);
 		const char *path = dbus_message_get_path(msg);
 		if (msg_member == "PropertyModified") {
-			if (ps_hal_query_capability((char*)path, "battery")) {
+			if (liblazy_hal_query_capability((char*)path, "battery")) {
 				pm->checkBatteryStateChanges();
 			}
-			else if (ps_hal_query_capability((char*)path, "ac_adapter")) {
+			else if (liblazy_hal_query_capability((char*)path, "ac_adapter")) {
 				pm->checkACStateChanges();
 			}
 		}
@@ -259,9 +239,9 @@ DBusConnection *DBus_Server::openSystemConnection()
 {
 	DBusError error;
 	dbus_error_init(&error);
+	int ret;
 
-	_connection = dbus_connection_open_private(DBUS_SYSTEM_BUS_SOCKET, &error);
-
+	_connection = dbus_bus_get(DBUS_BUS_SYSTEM, &error);
 	if (dbus_error_is_set(&error)) {
 		// only throw diag message. Real error message is thrown in main loop
 		pDebug(DBG_DIAG, "dbus_connection_open_private(): Error. (%s)", error.message);
@@ -269,23 +249,42 @@ DBusConnection *DBus_Server::openSystemConnection()
 		return NULL;
 	} else {
 		dbus_connection_set_exit_on_disconnect(_connection, 0);
-		pDebug(DBG_INFO, "dbus_connection_open_private(): Success.");
+		pDebug(DBG_INFO, "dbus_bus_get(): Success.");
 	}
 
-	dbus_bus_register(_connection, &error);
-
 	dbus_bus_request_name(_connection, PS_DBUS_SERVICE, 0, &error);
 
 	if (dbus_error_is_set(&error)) {
 		pDebug(DBG_ERR, "dbus_bus_request_name(): Error. (%s)", error.message);
 		if (_connection != NULL) {
-			dbus_connection_close(_connection);
 			dbus_connection_unref(_connection);
 		}
 		dbus_error_free(&error);
 		return NULL;
 	}
 
+	ret = dbus_bus_request_name(_connection, DBUS_SYSTEM_PM_INTERFACE,
+				    DBUS_NAME_FLAG_ALLOW_REPLACEMENT, &error);
+
+	if (dbus_error_is_set(&error)) {
+		pDebug(DBG_ERR, "dbus_bus_request_name(): Error. (%s)", error.message);
+		dbus_error_free(&error);
+	}
+
+	switch (ret) {
+	case DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER:
+		pDebug(DBG_INFO, "Successfully acquired the interface %s",
+		       DBUS_SYSTEM_PM_INTERFACE);
+		break;
+	case DBUS_REQUEST_NAME_REPLY_IN_QUEUE:
+		pDebug(DBG_INFO, "Placed in queue for interface %s", DBUS_SYSTEM_PM_INTERFACE);
+		break;
+	case DBUS_REQUEST_NAME_REPLY_ALREADY_OWNER:
+		pDebug(DBG_INFO, "Already owner of interface %s", DBUS_SYSTEM_PM_INTERFACE);
+	default:
+		break;
+	};
+
 	dbus_connection_add_filter(_connection, filter_function, NULL, NULL);
 
 	dbus_bus_add_match(_connection,
@@ -297,14 +296,6 @@ DBusConnection *DBus_Server::openSystemConnection()
 			   "type='signal'," "interface='org.freedesktop.DBus'," "member='NameOwnerChanged'",
 			   NULL);
 
-	dbus_bus_add_match(_connection,
-			   "type='signal'," "interface=org.freedesktop.Hal.Manager," "member=DeviceRemoved",
-			   NULL);
-
-	dbus_bus_add_match(_connection,
-			   "type='signal'," "interface=org.freedesktop.Hal.Manager," "member=DeviceAdded",
-			   NULL);
-
 	dbus_bus_add_match(_connection,
 			   "type='signal'," "interface=org.freedesktop.Hal.Device," "member=PropertyModified",
 			   NULL);
@@ -312,6 +303,22 @@ DBusConnection *DBus_Server::openSystemConnection()
 	return _connection;
 }
 
+bool DBus_Server::haveClient()
+{
+	int ret;
+
+	ret = dbus_bus_request_name(_connection, DBUS_SYSTEM_PM_INTERFACE,
+				    DBUS_NAME_FLAG_ALLOW_REPLACEMENT, NULL);
+
+	if (ret == DBUS_REQUEST_NAME_REPLY_ALREADY_OWNER) {
+		pDebug(DBG_DEBUG, "We own the interface %s", DBUS_SYSTEM_PM_INTERFACE);
+		return false;
+	}
+
+	pDebug(DBG_DEBUG, "We don't own the interface %s", DBUS_SYSTEM_PM_INTERFACE);
+	return true;
+}
+
 void DBus_Server::sendReply(DBusMessage * reply, int error_id)
 {
 
@@ -387,7 +394,7 @@ int DBus_Server::emitSignal(const char *signal, const char *value)
 }
 
 bool DBus_Server::sendMethodCall(const char *interface, const char *path,
-				 const char* object, const char *method,
+				 const char *object, const char *method,
 				 int first_arg_type, ...)
 {
 	if (_connection == NULL) {
@@ -417,6 +424,45 @@ bool DBus_Server::sendMethodCall(const char *interface, const char *path,
 	return true;
 }
 
+bool DBus_Server::sendMethodCallAndBlock(const char *interface, const char *path,
+					 const char *object, const char *method,
+					 int first_arg_type, ...)
+{
+	if (_connection == NULL) {
+		pDebug(DBG_INFO, "Connection to dbus not ready, skipping method call %s",
+		       method);
+		return false;
+	}
+
+	DBusError dbus_error;
+	DBusMessage *message;
+	DBusMessage *reply;
+	va_list var_args;
+
+	dbus_error_init(&dbus_error);
+
+	message = dbus_message_new_method_call( interface, path, object, method );
+
+	va_start(var_args, first_arg_type);
+	dbus_message_append_args_valist(message, first_arg_type, var_args);
+	va_end(var_args);
+
+	reply = dbus_connection_send_with_reply_and_block(_connection, message, -1, &dbus_error);
+
+	if (dbus_error_is_set(&dbus_error)) {
+		pDebug (DBG_ERR, "Could not send method call: %s\n", dbus_error.message);
+		dbus_message_unref( message );
+		dbus_error_free(&dbus_error);
+		return false;
+	}
+
+	dbus_message_unref( message );
+	dbus_message_unref(reply);
+	dbus_connection_flush(_connection);
+
+	return true;
+}
+
 bool DBus_Server::sendMethodCallWithReturn(const char *interface, const char *path,
 					   const char* object ,const char *method,
 					   int arg_type, void *value)
@@ -447,15 +493,16 @@ bool DBus_Server::sendMethodCallWithReturn(const char *interface, const char *pa
 		if (dbus_error_is_set(&dbus_error))
 			pDebug(DBG_WARN, "Could not get argument from reply: %s",
 			       dbus_error.message);
-		goto Error;
+		goto NoReply;
 	}
 			
 	dbus_connection_flush(_connection);
 	return true;
 	
+NoReply:
+	dbus_message_unref(reply);
 Error:
-	dbus_message_unref( message );
-	dbus_message_unref( reply );
+	dbus_message_unref(message);
 	dbus_error_free(&dbus_error);
 
 	return false;
