@@ -26,13 +26,13 @@
 #define POWERSAVE_DBUS_SERVER_H
 #define DBUS_API_SUBJECT_TO_CHANGE 1
 
-#define DBUS_NM_SERVICE                "org.freedesktop.NetworkManager"
-#define DBUS_NM_INTERFACE              "org.freedesktop.NetworkManager"
-#define DBUS_NM_PATH                   "/org/freedesktop/NetworkManager"
-#define DBUS_HAL_MANAGER_INTERFACE     "org.freedesktop.Hal.Manager"
-#define DBUS_HAL_DEVICE_INTERFACE      "org.freedesktop.Hal.Device"
-
-#include "powersave_dbus.h"
+#define DBUS_HAL_MANAGER_INTERFACE	"org.freedesktop.Hal.Manager"
+#define DBUS_HAL_DEVICE_INTERFACE	"org.freedesktop.Hal.Device"
+#define DBUS_HAL_UDI_COMPUTER		"/org/freedesktop/Hal/devices/computer"
+#define DBUS_HAL_INTERFACE		"org.freedesktop.Hal"
+#define DBUS_HAL_CPUFREQ_INTERFACE	"org.freedesktop.Hal.Device.CPUFreq"
+#define DBUS_SYSTEM_PM_INTERFACE	"org.freedesktop.Policy.Power"
+#define DBUS_HAL_SYSTEM_POWER_INTERFACE	"org.freedesktop.Hal.Device.SystemPowerManagement"
 
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
@@ -86,6 +86,10 @@ public:
 				   const char* object, const char *method,
 				   int first_arg_type, ...);
 
+	static bool sendMethodCallAndBlock(const char *interface, const char *path,
+					   const char* object, const char *method,
+					   int first_arg_type, ...);
+
 	/** @brief sends a method call with a return value
 	 *
 	 * @param interface the interface to sent to
@@ -109,6 +113,9 @@ public:
 	 */
 	static bool serviceHasOwner(const std::string &service);
 	
+	/** @brief check if another PolicyManager is available */
+	static bool haveClient();
+
 	/** @brief tries to reconnect to the dbus service 
 	 *
 	 * declared static to be used as callback function in main loop
