@@ -22,6 +22,7 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <algorithm>
 #include <sys/wait.h>
 #include <sys/time.h>
 
@@ -29,6 +30,7 @@
 #include "errno.h"
 #include "event.h"
 #include "config.h"
+#include "string.h"
 
 using namespace std;
 using namespace __gnu_cxx;
@@ -94,16 +96,9 @@ void Event::setupInternalActions()
 	_internalActions.push_back("ignore");
 	_internalActions.push_back("throttle");
 	_internalActions.push_back("dethrottle");
-	_internalActions.push_back("do_suspend_to_disk");
-	_internalActions.push_back("do_suspend_to_ram");
-	_internalActions.push_back("do_standby");
 	_internalActions.push_back("suspend_to_disk");
 	_internalActions.push_back("suspend_to_ram");
-	_internalActions.push_back("standby");
 	_internalActions.push_back("screen_saver");
-	_internalActions.push_back("reread_cpu_capabilities");
-	_internalActions.push_back("suspend_networkmanager");
-	_internalActions.push_back("resume_networkmanager");
 }
 
 string Event::name()
@@ -229,17 +224,6 @@ bool Event::execute_program(string acpi_event_line)
 void Event::setActions2Execute(list< string > actions)
 {
 	_programs_2_execute.clear();
-
-	insertAction(actions, true, "prepare_suspend_to_disk", "suspend_networkmanager");
-	insertAction(actions, false, "restore_after_suspend_to_disk", "resume_networkmanager");
-
-	insertAction(actions, true, "prepare_suspend_to_ram", "suspend_networkmanager");
-	insertAction(actions, false, "restore_after_suspend_to_ram", "resume_networkmanager");
-
-	insertAction(actions, true, "prepare_standby", "suspend_networkmanager");
-	insertAction(actions, false, "restore_after_standby", "resume_networkmanager");
-
-
 	_programs_2_execute = actions;
 
 }
@@ -334,11 +318,6 @@ void Event::start()
 	this->_starttime = cur_time.tv_sec * 1000 + cur_time.tv_usec / 1000;
 }
 
-void Event::increaseSleeptime(unsigned long time)
-{
-	_sleep_time += time;
-}
-
 string Event::currentAction()
 {
 	return *_current_program_2_execute;
