@@ -27,7 +27,6 @@
 
 #include <list>
 #include <string>
-#include <ext/slist>
 
 #include "config_pm.h"
 
@@ -95,9 +94,6 @@ public:
 	/** @brief starts the timer */
 	void start();
 
-	/** @brief adds time to sleep_time */
-	void increaseSleeptime(unsigned long time);
-
 	/** @brief sets the id of the event */
 	void setID(int id);
 
