@@ -28,8 +28,9 @@
 #include <dirent.h>
 #include "config.h"
 #include <list>
+#include <string.h>
 
-const string GeneralConfig::config_files[] = { "common", "thermal", "cpufreq", "battery", "sleep", "events" };
+const string GeneralConfig::config_files[] = { "common", "thermal", "cpufreq", "battery", "events" };
 
 GeneralConfig::GeneralConfig() 
  : current_scheme(NULL), AC_scheme(NULL), Battery_scheme(NULL), disable_CPU_freq(false), scheme_configs(NULL) 
@@ -57,14 +58,6 @@ GeneralConfig::GeneralConfig()
 
 	eventMap.insert(pair < string, Event > ("battery.info", Event("battery.info")));
 
-	eventMap.insert(pair < string, Event > ("global.suspend2disk", Event("global.suspend2disk")));
-	eventMap.insert(pair < string, Event > ("global.suspend2ram", Event("global.suspend2ram")));
-	eventMap.insert(pair < string, Event > ("global.standby", Event("global.standby")));
-	eventMap.insert(pair < string, Event > ("global.resume.suspend2disk", Event("global.resume.suspend2disk")));
-	eventMap.insert(pair < string, Event > ("global.resume.suspend2ram", Event("global.resume.suspend2ram")));
-	eventMap.insert(pair < string, Event > ("global.resume.standby", Event("global.resume.standby")));
-	eventMap.insert(pair < string, Event > ("global.suspend2disk.other", Event("global.suspend2disk.other")));
-
 	eventMap.insert(pair < string, Event > ("processor.performance", Event("processor.performance")));
 	eventMap.insert(pair < string, Event > ("processor.powersave", Event("processor.powersave")));
 	eventMap.insert(pair < string, Event > ("processor.dynamic", Event("processor.dynamic")));
