@@ -25,11 +25,14 @@
 #include "config.h"
 #include <sys/wait.h>
 #include <sys/time.h>
+#include <liblazy.h>
+#include <string.h>
+#include <errno.h>
+#include <stdlib.h>
 
 #include "event_management.h"
 #include "main_loop.h"
 #include "brightness.h"
-#include "clientConnection.h"
 #include "cpufreq_management.h"
 #include "globals.h"
 #include "pm_interface.h"
@@ -37,11 +40,6 @@
 
 using namespace Powersave::Globals;
 
-/* apm workaround variables for sleep modes ******************/
-PSD_SLEEP_STATE_REQUESTS PM_Interface::_requested_sleep_state = PSD_NO_SLEEP_REQUEST;
-bool PM_Interface::_sleep_triggered = false;
-/* apm workaround variables for sleep modes ******************/
-
 int PM_Interface::rereadConfig()
 {
 	int ret = config_obj->readConfFiles();
@@ -49,7 +47,7 @@ int PM_Interface::rereadConfig()
 	/* reset/reread everything that could have been changed in
 	   configs ... */
 	if (cpufreq->isSupported()) {
-		cpufreq->setConfigs();
+		cpufreq->setModes(config_obj->current_scheme->CPUFREQUENCY, _eM);
 	}
 	activateSettings();
 	return ret;
@@ -72,19 +70,25 @@ PM_Interface::PM_Interface()
 		kill(getpid(), SIGTERM);
 	}
 
-	_supported_sleeping_states = getSupportedSleepStates();
-
 	_cooling_mode_supported = true;
 	_thermal_trip_points_supported = true;
+	_can_suspend_to_disk = true;
+	_can_suspend_to_ram = true;
 
 	// allocate memory for event management object
 	_eM = new EventManagement();
 
-	// create a new client connection object
-	_cC = new ClientConnection();
+	_brightness = new Brightness();
 
-	_brightness = Brightness::Probe();
-	_brightness->Init();
+	int can;
+	liblazy_hal_get_property_bool(DBUS_HAL_UDI_COMPUTER,
+				      "power_management.can_suspend_to_disk", &can);
+	if (can != 1)
+		_can_suspend_to_disk = false;
+	liblazy_hal_get_property_bool(DBUS_HAL_UDI_COMPUTER,
+				      "power_management.can_suspend_to_ram", &can);
+	if (can != 1)
+		_can_suspend_to_ram = false;
 }
 
 PM_Interface::~PM_Interface()
@@ -93,7 +97,6 @@ PM_Interface::~PM_Interface()
 	pDebug(DBG_DEBUG, "PM Destructor: delete allocated Objects");
 
 	_eM->executeEvent("daemon.terminate");
-	delete(_cC);
 	delete(_eM);
 	delete(_brightness);
 
@@ -106,8 +109,6 @@ int PM_Interface::start()
 	// ********  trigger start event ****************/
 	_eM->executeEvent("daemon.start");
 
-	_devices.init();	
-
 	if (_battery.updateBatteryState(_cur_state.AC_STATE, _eM) < 0) {
 		pDebug(DBG_INFO, "No battery available.");
 	} else {
@@ -272,16 +273,6 @@ bool PM_Interface::checkThrottling()
 	return _throttleInterface.updateCPUState(_eM);
 }
 
-void PM_Interface::checkDevice(char *udi, bool added)
-{
-	if (added) {
-		_devices.checkDeviceAdded(udi);
-	}
-	else {
-		_devices.checkDeviceRemoved(udi);
-	}
-}
-
 int PM_Interface::updateACState()
 {
 	int changed;
@@ -314,9 +305,9 @@ int PM_Interface::updateTemperatureState()
 	/* is also THERM_MODE but C (library) forbids the declaration */
 	int temp_state = OK;
 
-	for (x = 0; config_obj->current_scheme->thermal_zones[x].present &&
-		    ((state = getThermalZoneState(x)) >= OK) &&
-		    x < MAX_THERMAL_ZONES; x++) {
+	for (x = 0; x < MAX_THERMAL_ZONES &&
+		     (config_obj->current_scheme->thermal_zones[x].present) &&
+		     ((state = getThermalZoneState(x)) >= OK); x++) {
 		config_obj->current_scheme->thermal_zones[x].state = state;
 		temp_state = max(state, temp_state);
 	}
@@ -355,7 +346,6 @@ int PM_Interface::activateScheme(const string &scheme_name)
 		       "is highly experimental. Please be careful!");
 	}
 
-
 	activateSettings();
 	return 1;
 }
@@ -384,8 +374,7 @@ int PM_Interface::activateScheme(AC_ADAPTER_STATE ac_state)
 void PM_Interface::activateSettings()
 {
 	// Switch kernel/userspace control during runtime
-	if (config_obj->current_scheme->CPUFREQ_CONTROL != cpufreq->controlMode()
-		|| !cpufreq->isSupported()) {
+	if (config_obj->current_scheme->CPUFREQ_CONTROL != cpufreq->controlMode()) {
 
 		pDebug(DBG_DIAG, "Change cpufreq control to: %s",
 		       ((config_obj->current_scheme->CPUFREQ_CONTROL == CPUFREQ_USERSPACE)
@@ -394,18 +383,15 @@ void PM_Interface::activateSettings()
 		delete cpufreq;
 		cpufreq = NULL;
 		cpufreq = new CpufreqManagement();
-		cpufreq->init();
 	}
 
-	cpufreq->setConfigs();
-
 	/* set new CPU freq mode */
 	if (!cpufreq->setModes(config_obj->current_scheme->CPUFREQUENCY, _eM) < 0) {
 		pDebug(DBG_WARN, "Could not set CPUFreq mode");
 	}
 
-	// only adjust brightness if we have no client caring about
-	if (!_cC->checkClientCapabilities(CAPABILITY_BRIGHTNESS)) {
+	// disable brightness in powersaved until we have a interface clients can grab
+	if (!DBus_Server::haveClient()) {
 		switch (config_obj->current_scheme->DISPLAY_BRIGHTNESS) {
 		case -1:		// ignore
 			break;
@@ -423,9 +409,6 @@ void PM_Interface::activateSettings()
 		break;
 		}
 	}
-	
-	_devices.update(config_obj->current_scheme->dpmClasses);
-
 	main_loop->updateCallbacks();
 }
 
@@ -443,88 +426,108 @@ void PM_Interface::dethrottle()
 	}
 }
 
-void PM_Interface::resume(CPUFREQ_MODE cpufreq_mode)
+/* mainly copied from liblazy_dbus_send_method_call implementation. Just
+ * added var_args list and INT_MAX as timeout */
+int PM_Interface::sendSleepRequest(const char *method, int first_arg_type, ...)
+{
+	DBusError	dbus_error;
+	DBusConnection	*dbus_connection	= NULL;
+	DBusMessage	*message		= NULL;
+	DBusMessage	*reply			= NULL;
+	int		ret			= 0;
+	va_list		var_args;
+
+	dbus_error_init(&dbus_error);
+
+	dbus_connection = dbus_bus_get(DBUS_BUS_SYSTEM, &dbus_error);
+	if (dbus_connection == NULL || dbus_error_is_set(&dbus_error)) {
+		fprintf(stderr, "Connection to dbus not ready, skipping method call %s: %s\n",
+			method, dbus_error.message);
+		ret = -1;
+		goto Free_Error;
+	}
+
+	message = dbus_message_new_method_call(DBUS_HAL_INTERFACE, DBUS_HAL_UDI_COMPUTER,
+					       DBUS_HAL_SYSTEM_POWER_INTERFACE, method);
+	va_start(var_args, first_arg_type);
+	dbus_message_append_args_valist(message, first_arg_type, var_args);
+	va_end(var_args);
+
+	reply = dbus_connection_send_with_reply_and_block(dbus_connection,
+							  message, 1,
+							  &dbus_error);
+	if (dbus_error_is_set(&dbus_error)) {
+		/* ignore timeout errors because it's possible that we are suspending > 6 hours */
+		if (!dbus_error_has_name(&dbus_error, "org.freedesktop.DBus.Error.NoReply")) {
+			fprintf(stderr, "Received error reply: %s\n", dbus_error.message);
+			ret = -1;
+		}
+	}
+	
+	dbus_message_unref(message);
+	dbus_connection_unref(dbus_connection);
+Free_Error:
+	dbus_error_free(&dbus_error);
+	return ret;
+}
+
+bool PM_Interface::suspendToDisk()
+{
+	if (!_can_suspend_to_disk) {
+		pDebug(DBG_WARN, "ACPI S4 state not available");
+		return false;
+	}
+
+	if (liblazy_hal_is_caller_privileged("org.freedesktop.hal.power-management.hibernate") != 1)
+		return false;
+	else if (sendSleepRequest("Hibernate", DBUS_TYPE_INVALID)) {
+				 pDebug(DBG_ERR, "Could not send suspend to disk request to HAL\n");
+				 return false;
+	} else
+		pDebug(DBG_DEBUG, "Suspend to disk request sent.\n");
+	
+	pDebug(DBG_INFO, "Set machine into suspend to disk (S4) mode");
+
+	return true;
+}
+
+bool PM_Interface::suspendToRam()
+{
+	if (!_can_suspend_to_ram) {
+		pDebug(DBG_WARN, "ACPI S3 state not available");
+		return false;
+	}
+
+	int wake_up = 0;
+
+	if (liblazy_hal_is_caller_privileged("org.freedesktop.hal.power-management.suspend") != 1)
+		return false;
+	else if (sendSleepRequest("Suspend",
+				    DBUS_TYPE_INT32,
+				    &wake_up,
+				    DBUS_TYPE_INVALID)) {
+		pDebug(DBG_ERR, "Could not send suspend to ram request to HAL\n");
+		return false;
+	} else
+		pDebug(DBG_DEBUG, "Suspend to ram request sent.\n");
+
+	pDebug(DBG_INFO, "Set machine into suspend2ram (S3) mode");
+
+	return true;
+}
+
+void PM_Interface::resume()
 {
 	pDebug(DBG_DIAG, "Daemon reinitialises system states, resume finished");
-	_requested_sleep_state = PSD_NO_SLEEP_REQUEST;
-	// reset frequency which may have changed without noticing it
-	cpufreq->reinitSpeeds();
-	/* reset CPU freq mode */
-	if (cpufreq->isSupported())
-		cpufreq->setModes(cpufreq_mode, _eM);
 
 	checkACStateChanges();
 	checkBatteryStateChanges();
 }
 
-void PM_Interface::sleep_wrapper(const string &event)
-{
-	static bool before_sleep = true;
-	static struct timeval cur_time;
-	static struct timezone dummy;
-	static CPUFREQ_MODE cpufreq_mode;
-
-	if (before_sleep) {
-		ignore_buttons(true);
-
-		if (cpufreq->isSupported()) {
-			cpufreq_mode = cpufreq->getMode();
-			cpufreq->setModes(_PERFORMANCE, _eM);
-		}
-
-		pDebug(DBG_INFO, "Set machine into sleep mode");
-
-		before_sleep = false;
-		gettimeofday(&cur_time, &dummy);
-	} else {
-		// the time where we went to sleep in milliseconds
-		unsigned long sleeptime = cur_time.tv_sec * 1000 + cur_time.tv_usec / 1000;
-
-		gettimeofday(&cur_time, &dummy);
-
-		// the time were we are back in milliseconds
-		unsigned long wakeuptime = cur_time.tv_sec * 1000 + cur_time.tv_usec / 1000;
-
-		// substract the time we slept from all events
-		_eM->adjustTimeouts(wakeuptime - sleeptime);
-		pDebug(DBG_INFO, "Back from %s inside sleep_wrapper", event.c_str());
-
-		resume(cpufreq_mode);
-
-		before_sleep = true;
-
-		// throw a resume event
-		_eM->executeEvent("global.resume." + event);
-	}
-}
-
-void PM_Interface::suspendNetworkManager()
-{
-	if (!DBus_Server::serviceHasOwner(DBUS_NM_SERVICE)) {
-		pDebug(DBG_DIAG, "Networkmanager not running");
-		return;
-	}
-
-	DBus_Server::sendMethodCall(DBUS_NM_INTERFACE, DBUS_NM_PATH,
-				    DBUS_NM_SERVICE, "sleep", DBUS_TYPE_INVALID);
-}
-
-void PM_Interface::resumeNetworkManager()
-{
-	if (!DBus_Server::serviceHasOwner(DBUS_NM_INTERFACE)) {
-		pDebug(DBG_DIAG, "Networkmanager not running");
-		return;
-	}
-
-	DBus_Server::sendMethodCall(DBUS_NM_INTERFACE, DBUS_NM_PATH,
-				    DBUS_NM_SERVICE, "wake", DBUS_TYPE_INVALID);
-}
-
 int PM_Interface::executeScript(const string &script, const string &param)
 {
 	int ret = -1;
 	int pid;
-	int status;
 	char *argv[3];
 	argv[0] = new char[script.size() + 1];
 	argv[1] = new char[param.size() + 1];
@@ -566,39 +569,6 @@ int PM_Interface::executeScript(const string &script, const string &param)
 	} else if (pid == -1) {
 		pDebug(DBG_WARN, "Could not fork for sleep script");
 	} else {
-		// if the script is the sleep script, wait for its return
-		if (script == ACPI_SLEEP_SCRIPT) {
-
-			// wait for the sleep script in case of a suspend
-			signal(SIGCLD, SIG_DFL);
-
-			if (waitpid(pid, &status, 0) < 0) {
-				if (errno == ECHILD) {
-					pDebug(DBG_DIAG, "Sleep script already exited.");
-				} else {
-					pDebug(DBG_ERR, "Sleep script failed - %s", strerror(errno));
-				}
-			} else if (WIFEXITED(status)) {
-				if (WEXITSTATUS(status)) {
-					pDebug(DBG_WARN,
-					       "Program to trigger sleep (%s) failed and exited with status %d",
-					       full_path_to_script.c_str(), WEXITSTATUS(status));
-					ret = -1;
-				} else {
-					/* everything is alright, go on executing ... */
-					pDebug(DBG_INFO, "Program %s to trigger sleep executed successfully",
-					       full_path_to_script.c_str());
-					ret = 0;
-				}
-			} else if (WIFSIGNALED(status)) {
-				pDebug(DBG_DIAG, "Program %s exited on signal %d",
-				       full_path_to_script.c_str(), WTERMSIG(status));
-				ret = -1;
-			}
-
-			// ignore children further on
-			signal(SIGCLD, SIG_IGN);
-		}
 		// no need to wait for script to return
 	}
 	return ret;
@@ -609,7 +579,7 @@ int PM_Interface::screenlock(const string &param)
 
 	DBus_Server::emitSignal("Screenlock", param.c_str());
 
-	if (!_cC->checkClientCapabilities(CAPABILITY_SCREENLOCK)) {
+	if (!DBus_Server::haveClient()) {
 		executeScript("do_screen_saver", param);
 	}
 	return 1;
@@ -619,115 +589,39 @@ int PM_Interface::x_notification(const string &param)
 {
 	DBus_Server::emitSignal("Notification", param.c_str());
 
-	if (!_cC->checkClientCapabilities(CAPABILITY_NOTIFICATIONS)) {
+	if (!DBus_Server::haveClient()) {
 		executeScript("do_x_notification", param);
 	}
 	return 1;
 }
 
-void PM_Interface::ignore_buttons(bool ignore)
+DBUS_ERROR PM_Interface::handleScriptsMessage(DBusMessage *msg, const string &msg_member)
 {
-	pDebug(DBG_DIAG, "ignore_buttons is set to: %d", ignore);
-	_sleep_triggered = ignore;
-}
-
-bool PM_Interface::haveSuspend2()
-{
-	if (access("/proc/suspend2", F_OK) < 0
-		&& access("/sys/power/suspend2", F_OK) < 0) {
-                return false;
-	}
-
-	return true;
-}
-
-DBUS_ERROR PM_Interface::handleDBusRequest(DBusMessage * msg, DBusMessage * reply, POWERSAVE_MESSAGE_TYPE type)
-{
-
-	string msg_member = dbus_message_get_member(msg);
-	string sender = dbus_message_get_sender(msg);
-	uint32_t serial = dbus_message_get_serial(msg);
-
-	/** @todo: Debug only, throw out when working... */
-	pDebug(DBG_INFO, "Received msg: '%s'", msg_member.c_str());
-	pDebug(DBG_DEBUG, "Obj.path '%s' serial '%d' from '%s'", dbus_message_get_path(msg), serial, sender.c_str());
-
-	switch (type) {
-	case MANAGER_MESSAGE:
-		return handleManagerMessage(msg);
-		break;
-	case SCRIPTS_MESSAGE:	       
-		return handleScriptsMessage( msg );
-		break;
-	case REQUEST_MESSAGE:
-		return handleRequestMessage(msg, reply);
-		break;
-	case ACTION_MESSAGE:
-		return handleActionMessage(msg);
-		break;
-	default:
-		/* Should never happen -> get rid of message? */
-		pDebug(DBG_ERR, "Received invalid message");
-		return REPLY_INVALID_INTERFACE;
-	}
-
-	return REPLY_GENERAL_ERROR;
-}
-
-DBUS_ERROR PM_Interface::handleManagerMessage(DBusMessage * msg)
-{
-	string msg_member = dbus_message_get_member(msg);
-	string sender = dbus_message_get_sender(msg);
-
-	pDebug(DBG_DIAG, "Handling manager request");
-	if (msg_member == "Connect") {
-		int capabilities;
-		/* add client. No 'request string/modes' check so far */
-		if (!dbusGetMessageInteger(msg, &capabilities, 0)) {
-			if (_cC->addClient(sender.c_str(), capabilities)) {
-				pDebug(DBG_DIAG, "added Client: %s", sender.c_str());
-				return REPLY_SUCCESS;
-			} else
-				return REPLY_INVALID_PARAM;
-		} else
-			return REPLY_INVALID_PARAM;
-	} else if (msg_member == "Disconnect") {
-		_cC->checkClientRemoval(sender.c_str());
-		return REPLY_SUCCESS;
-	} else
-		return REPLY_INVALID_METHOD;
-
-	return REPLY_GENERAL_ERROR;
-}
-
-DBUS_ERROR PM_Interface::handleScriptsMessage( DBusMessage *msg ) {
- 	string msg_member = dbus_message_get_member(msg);
- 	string sender = dbus_message_get_sender(msg);
- 
- 	char *dummy = "";
+ 	char dummy[] = "";
 
 	pDebug (DBG_DIAG, "Handling Scripts request");
 	if (msg_member == "ScriptReturn") {
 		int event_id, request;
 
 		// get the event id
-		if (dbusGetMessageInteger(msg, &event_id, 0) < 0) {
+		if (liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_INT32, &event_id, 0) < 0) {
 			pDebug(DBG_WARN, "Script returned but we could not get the event id");
 			return REPLY_INVALID_PARAM;
 		}
 		// get the so called mode ( notify, progress, true, false )
-		if (!dbusGetMessageInteger(msg, &request, 1) < 0) {
+		if (!liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_INT32, &request, 1) < 0) {
 			pDebug(DBG_WARN, "Script returned but we could not to get the request");
 			return REPLY_INVALID_PARAM;
 		}
 		// get the message
-		if (dbusGetMessageString(msg, &dummy, 0) < 0) {
+		if (!liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_STRING, &dummy, 0) < 0) {
 			pDebug(DBG_INFO, "Script returned but we could not to get the message."
 			       " Continuing anyway...");
-			dummy = "";
+			strcpy(dummy, "");
 		}
 
-		pDebug(DBG_DEBUG, "Script returned: event id: %d, request: %d, message: '%s'", event_id, request, dummy);
+		pDebug(DBG_DEBUG, "Script returned: event id: %d, request: %d, message: '%s'",
+		       event_id, request, dummy);
 
 		string str_dummy = dummy;
 		_eM->checkScriptReturn(event_id, request, str_dummy);
@@ -739,88 +633,13 @@ DBUS_ERROR PM_Interface::handleScriptsMessage( DBusMessage *msg ) {
 	return REPLY_GENERAL_ERROR;
 }
 
-DBUS_ERROR PM_Interface::handleRequestMessage(DBusMessage * msg, DBusMessage * reply)
+DBUS_ERROR PM_Interface::handleDBusMessage(DBusMessage *msg, DBusMessage *reply,
+					   const string &msg_member)
 {
-
-	string msg_member = dbus_message_get_member(msg);
-	char *dummy = "";
+	char *dummy;
 
 	/** @todo Also reply REPLY_HW_NOT_SUPPORTED for suspend*/
-	if (msg_member == "AllowedSuspendToDisk" || msg_member == "suspend_to_disk_allowed") {
-		if (config_obj->current_scheme->USER_SUSPEND2DISK_DISABLED)
-			return REPLY_DISABLED;
-		else
-			return REPLY_SUCCESS;
-	} else if (msg_member == "AllowedSuspendToRam" || msg_member == "suspend_to_ram_allowed") {
-		if (config_obj->current_scheme->USER_SUSPEND2RAM_DISABLED)
-			return REPLY_DISABLED;
-		else
-			return REPLY_SUCCESS;
-	} else if (msg_member == "AllowedStandby" || msg_member == "standby_allowed") {
-		if (config_obj->current_scheme->USER_STANDBY_DISABLED)
-			return REPLY_DISABLED;
-		else
-			return REPLY_SUCCESS;
-	} else if (msg_member == "BatteryState") {
-		switch (_battery.batteryState()) {
-		case BAT_NONE_STATE:
-			return REPLY_HW_NOT_SUPPORTED;
-			break;
-		case BAT_NORM_STATE:
-			dummy = "normal";
-			break;
-		case BAT_WARN_STATE:
-			dummy = "warning";
-			break;
-		case BAT_LOW_STATE:
-			dummy = "low";
-			break;
-		case BAT_CRIT_STATE:
-			dummy = "critical";
-			break;
-		default:
-			return REPLY_GENERAL_ERROR;
-			break;
-		}
-		dbus_message_append_args(reply, DBUS_TYPE_STRING, &dummy, DBUS_TYPE_INVALID);
-		return REPLY_SUCCESS;
-	} else if (msg_member == "CpufreqPolicy") {
-		const char *policy;
-		if (!cpufreq->isSupported())
-			return REPLY_HW_NOT_SUPPORTED;
-
-		switch (cpufreq->getMode()) {
-		case _PERFORMANCE:
-			policy = "performance";
-			break;
-		case _POWERSAVE:
-			policy = "powersave";
-			break;
-		case _DYNAMIC:
-			policy = "dynamic";
-			break;
-		default:
-			return REPLY_HW_NOT_SUPPORTED;
-		}
-		dbus_message_append_args(reply, DBUS_TYPE_STRING, &policy, DBUS_TYPE_INVALID);
-		return REPLY_SUCCESS;
-	} else if (msg_member == "AcPower") {
-		switch (_cur_state.AC_STATE) {
-		case AC_ONLINE:
-			dummy = "on";
-			break;
-		case AC_OFFLINE:
-			dummy = "off";
-			break;
-		case AC_UNKNOWN:
-			dummy = "unknown";
-			break;
-		default:
-			return REPLY_HW_NOT_SUPPORTED;
-		}
-		dbus_message_append_args(reply, DBUS_TYPE_STRING, &dummy, DBUS_TYPE_INVALID);
-		return REPLY_SUCCESS;
-	} else if (msg_member == "SchemesGet") {
+	if (msg_member == "SchemesGet") {
 		int active = -1;
 		int battery = -1;
 		int ac_power = -1;
@@ -868,7 +687,7 @@ DBUS_ERROR PM_Interface::handleRequestMessage(DBusMessage * msg, DBusMessage * r
 	} else if (msg_member == "SchemesGetDescription") {
 		SchemeConfig *scheme;
 		const char *description;
-		if (!dbusGetMessageString(msg, &dummy, 0)) {
+		if (!liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_STRING, &dummy, 0)) {
 			scheme = config_obj->getScheme(dummy);
 
 			if (scheme == NULL) {
@@ -884,220 +703,9 @@ DBUS_ERROR PM_Interface::handleRequestMessage(DBusMessage * msg, DBusMessage * r
 		else {
 			return REPLY_INVALID_PARAM;
 		}
-	} else if (msg_member == "BrightnessGet") {
-		int brt = _brightness->Get();
-
-		if (brt < 0) {
-			return REPLY_HW_NOT_SUPPORTED;
-		}
-
-		dbus_message_append_args(reply, DBUS_TYPE_INT32, &brt, DBUS_TYPE_INVALID);
-		return REPLY_SUCCESS;
-
-	} else if (msg_member == "BrightnessGetPercent") {
-		int brt = _brightness->GetPercent();
-
-		if (brt < 0) {
-			return REPLY_HW_NOT_SUPPORTED;
-		}
-
-		dbus_message_append_args(reply, DBUS_TYPE_INT32, &brt, DBUS_TYPE_INVALID);
-		return REPLY_SUCCESS;
-
-	} else if (msg_member == "BrightnessLevelsGet") {
-		int brt = _brightness->GetLevels();
-
-		if (brt < 0) {
-			return REPLY_HW_NOT_SUPPORTED;
-		}
-
-		dbus_message_append_args(reply, DBUS_TYPE_INT32, &brt, DBUS_TYPE_INVALID);
-		return REPLY_SUCCESS;
-	} else if (msg_member == "DpmDevicesGet"){
-		if (!config_obj->current_scheme->DPM_ENABLED) {
-			pDebug(DBG_DIAG, "Device power management is disabled in config.");
-			return REPLY_DISABLED;
-		}
-
-		if (!dbusGetMessageString(msg, &dummy, 0)) {
-			list< string > udis;
-			list< DPM_POWER_STATE > power_states;
-
-			int i = 0;
-			while (i != DPM_CLASS_MAX) {
-				if (!strcmp(dummy, DPM_CLASS_NAMES[i])) {
-					_devices.getDevices((DPM_DEVICE_CLASS)i, udis, power_states);
-					break;
-				}
-				i++;
-			}
-			
-			list< DPM_POWER_STATE >::iterator ti = power_states.begin();
-			for (list< string>::iterator it = udis.begin();
-			     it != udis.end(); ++it) {
-
-				dummy = (char*)it->c_str();
-				dbus_message_append_args(reply, DBUS_TYPE_STRING, &dummy,
-							 DBUS_TYPE_INT32, &(*ti),
-							 DBUS_TYPE_INVALID);
-				
-				++ti;
-			}
-
-			return REPLY_SUCCESS;
-		}
-
-		return REPLY_INVALID_PARAM;
-	} else if (msg_member == "DpmClassesGet") {
-		if (!config_obj->current_scheme->DPM_ENABLED) {
-			pDebug(DBG_DIAG, "Device power management is disabled in config.");
-			return REPLY_DISABLED;
-		}
-
-		int i = 0;
-		while (i != DPM_CLASS_MAX) {
-			dbus_message_append_args(reply, DBUS_TYPE_STRING, &(DPM_CLASS_NAMES[i]),
-						 DBUS_TYPE_INVALID);
-			i++;
-		}
-		
-		return REPLY_SUCCESS;
-	} else if (msg_member == "ClientsGet") {
-		list< string > names;
-		list< int > caps;
-		_cC->getClients(names, caps);
-		
-		for (list< string >::iterator it = names.begin();
-		     it != names.end(); ++it) {
-
- 			dbus_message_append_args(reply, DBUS_TYPE_STRING, &(*it),
-						 DBUS_TYPE_INVALID);
-		}
-
-		for (list< int >::iterator it = caps.begin();
-		     it != caps.end(); ++it) {
-			dbus_message_append_args(reply, DBUS_TYPE_INT32, &(*it),
-						 DBUS_TYPE_INVALID);
-		}
-		return REPLY_SUCCESS;
-	} else if (msg_member == "supp_sleep_states") {
-
-	} else {
-		return REPLY_INVALID_METHOD;
-	}
-
-	return REPLY_GENERAL_ERROR;
-}
-
-DBUS_ERROR PM_Interface::handleActionMessage(DBusMessage * msg)
-{
-
-	string msg_member = dbus_message_get_member(msg);
-	char *dummy = "";
-
-	if (msg_member == "SuspendToDisk" || msg_member == "suspend_to_disk") {
-		string interface = dbus_message_get_interface(msg);
-		if (config_obj->current_scheme->USER_SUSPEND2DISK_DISABLED
-			&& interface != PS_DBUS_ADMIN_INTERFACE) {
-			pDebug(DBG_DIAG, "Suspend to disk is disabled in config.");
-			return REPLY_DISABLED;
-		} else {
-			pDebug(DBG_INFO, "Client has requested suspend2disk");
-			_requested_sleep_state = PSD_SUSPEND2DISK;
-			/* used for workaround for apm to remembemer triggered sleep state (not needed at
-			   this point any more)**** */
-
-			// executing event now triggers suspend2disk, using do_suspend_to_disk variable
-			if (haveSuspend2())
-				_eM->executeEvent("global.suspend2disk.other");
-			else
-				_eM->executeEvent("global.suspend2disk");
-			return REPLY_SUCCESS;
-		}
-	} else if (msg_member == "SuspendToRam" || msg_member == "suspend_to_ram") {
-		string interface = dbus_message_get_interface(msg);
-		if (config_obj->current_scheme->USER_SUSPEND2RAM_DISABLED
-			&& interface != PS_DBUS_ADMIN_INTERFACE) {
-			pDebug(DBG_DIAG, "Suspend2ram is disabled in config.");
-			return REPLY_DISABLED;
-		} else if (!(_supported_sleeping_states & APM_SUSPEND) && !(_supported_sleeping_states & ACPI_S3)) {
-			pDebug(DBG_DIAG, "Suspend2ram is not supported");
-			return REPLY_HW_NOT_SUPPORTED;
-		} else {
-			pDebug(DBG_INFO, "Client has requested suspend2ram");
-			_requested_sleep_state = PSD_SUSPEND2RAM;
-			// executing event now triggers suspend2ram, using do_suspend2ram variable!
-			_eM->executeEvent("global.suspend2ram");
-			//suspend2ram();
-			return REPLY_SUCCESS;
-		}
-	} else if (msg_member == "Standby" || msg_member == "standby") {
-		string interface = dbus_message_get_interface(msg);
-		if (config_obj->current_scheme->USER_STANDBY_DISABLED
-		    && interface != PS_DBUS_ADMIN_INTERFACE) {
-			pDebug(DBG_DIAG, "Standby is disabled in config.");
-			return REPLY_DISABLED;
-		} else if (!(_supported_sleeping_states & APM_STANDBY) && !(_supported_sleeping_states & ACPI_S1)) {
-			pDebug(DBG_DIAG, "Standby is not supported");
-			return REPLY_HW_NOT_SUPPORTED;
-		} else {
-			pDebug(DBG_INFO, "Client has requested standby");
-			/* workaround for apm to remembemer triggered sleep state ***************
-			   but defined for whole PM_Interface to avoid dynamic cast */
-			_requested_sleep_state = PSD_STANDBY;
-			/* workaround for apm to remembemer triggered sleep state ************** */
-			// executing event now triggers suspend2ram, using do_suspend_to_ram variable!
-			_eM->executeEvent("global.standby");
-			//suspend2ram();
-			return REPLY_SUCCESS;
-		}
-	} else if (msg_member == "CpufreqPerformance") {
-		if (cpufreq->isSupported()) {
-			if (cpufreq->getMode() != _PERFORMANCE) {
-				if (cpufreq->setModes(_PERFORMANCE, _eM) < 0) {
-					pDebug(DBG_ERR, "Could not set performance mode");
-					return REPLY_HW_NOT_SUPPORTED;
-				}
-				_throttleInterface.restart();
-
-				return REPLY_SUCCESS;
-			} else
-				return REPLY_ALREADY_SET;
-		} else
-			return REPLY_HW_NOT_SUPPORTED;
-	} else if (msg_member == "CpufreqPowersave") {
-		if (cpufreq->isSupported()) {
-			if (cpufreq->getMode() != _POWERSAVE) {
-				if (cpufreq->setModes(_POWERSAVE, _eM) < 0) {
-					pDebug(DBG_ERR, "Could not set powersave mode");
-					return REPLY_HW_NOT_SUPPORTED;
-				}
-				// this only concerns dynamic events
-				_throttleInterface.restart();
-
-				return REPLY_SUCCESS;
-			} else
-				return REPLY_ALREADY_SET;
-		} else
-			return REPLY_HW_NOT_SUPPORTED;
-	} else if (msg_member == "CpufreqDynamic") {
-		if (cpufreq->isSupported()) {
-			if (cpufreq->getMode() != _DYNAMIC) {
-				if (cpufreq->setModes(_DYNAMIC, _eM) < 0) {
-					pDebug(DBG_ERR, "Could not set dynamic mode");
-					return REPLY_HW_NOT_SUPPORTED;
-				}
-				// this only concerns dynamic events
-				_throttleInterface.restart();
-
-				return REPLY_SUCCESS;
-			} else
-				return REPLY_ALREADY_SET;
-		} else
-			return REPLY_HW_NOT_SUPPORTED;
 	} else if (msg_member == "CpufreqCPUEnable") {
 		int value;
-		if (!dbusGetMessageInteger(msg, &value, 0)) {
+		if (!liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_INT32, &value, 0)) {
 			int ret = cpufreq->enableCPU(value); 
 			if (ret < 0)
 				return REPLY_HW_NOT_SUPPORTED;
@@ -1110,7 +718,7 @@ DBUS_ERROR PM_Interface::handleActionMessage(DBusMessage * msg)
 		}
 	} else if (msg_member == "CpufreqCPUDisable") {
 		int value;
-		if (!dbusGetMessageInteger(msg, &value, 0)) {
+		if (!liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_INT32, &value, 0)) {
 			int ret = cpufreq->disableCPU(value); 
 			if (ret < 0)
 				return REPLY_HW_NOT_SUPPORTED;
@@ -1124,7 +732,7 @@ DBUS_ERROR PM_Interface::handleActionMessage(DBusMessage * msg)
 	} else if (msg_member == "Ping") {
 		return REPLY_SUCCESS;
 	} else if (msg_member == "SchemesSet") {
-		if (!dbusGetMessageString(msg, &dummy, 0)) {
+		if (!liblazy_dbus_message_get_basic_arg(msg, DBUS_TYPE_STRING, &dummy, 0)) {
 			int r = activateScheme(dummy);
 			if (r == 0) {
 				return REPLY_ALREADY_SET;
@@ -1139,76 +747,6 @@ DBUS_ERROR PM_Interface::handleActionMessage(DBusMessage * msg)
 			}
 		} else
 			return REPLY_INVALID_PARAM;
-	} else if (msg_member == "BrightnessSet") {
-		int value;
-		if (!dbusGetMessageInteger(msg, &value, 0)) {
-			_brightness->Set(value);
-			return REPLY_SUCCESS;
-		} else {
-			return REPLY_GENERAL_ERROR;
-		}
-	} else if (msg_member == "BrightnessSetPercent") {
-		int value;
-		if (!dbusGetMessageInteger(msg, &value, 0)) {
-			_brightness->SetPercent(value);
-			return REPLY_SUCCESS;
-		} else {
-			return REPLY_GENERAL_ERROR;
-		}
-	} else if (msg_member == "BrightnessMin") {
-		_brightness->Min();
-		return REPLY_SUCCESS;
-	} else if (msg_member == "BrightnessMed") {
-		_brightness->Med();
-		return REPLY_SUCCESS;
-	} else if (msg_member == "BrightnessMax") {
-		_brightness->Max();
-		return REPLY_SUCCESS;
-	} else if (msg_member == "BrightnessUp") {
-		_brightness->Up();
-		return REPLY_SUCCESS;
-	} else if (msg_member == "BrightnessDown") {
-		_brightness->Down();
-		return REPLY_SUCCESS;
-	} else if (msg_member == "DpmDevicesSuspend") {
-		if (!config_obj->current_scheme->DPM_ENABLED) {
-			pDebug(DBG_DIAG, "Device power management is disabled in config.");
-			return REPLY_DISABLED;
-		}
-		int device_num = -1;
-		if (!dbusGetMessageString(msg, &dummy, 0)
-		    && !dbusGetMessageInteger(msg, &device_num, 0)) {
-
-			int i = 0;
-			while (i != DPM_CLASS_MAX) {
-				if (!strcmp(dummy, DPM_CLASS_NAMES[i])) {
-					_devices.suspend((DPM_DEVICE_CLASS)i, device_num);
-					return REPLY_SUCCESS;
-				}
-				i++;
-			}
-		}
-
-		return REPLY_INVALID_PARAM;
-	} else if (msg_member == "DpmDevicesResume") {	
-		if (!config_obj->current_scheme->DPM_ENABLED) {
-			pDebug(DBG_DIAG, "Device power management is disabled in config.");
-			return REPLY_DISABLED;
-		}
-		int device_num = -1;
-		if (!dbusGetMessageString(msg, &dummy, 0)
-		    && !dbusGetMessageInteger(msg, &device_num, 0)) {
-
-			int i = 0;
-			while (i != DPM_CLASS_MAX) {
-				if (!strcmp(dummy, DPM_CLASS_NAMES[i])) {
-					_devices.resume((DPM_DEVICE_CLASS)i, device_num);
-					return REPLY_SUCCESS;
-				}
-				i++;
-			}
-		}
-		return REPLY_INVALID_PARAM;
 	} else {
 		return REPLY_INVALID_METHOD;
 	}
