@@ -35,13 +35,10 @@ SchemeConfig::SchemeConfig(const string &file_name, const GeneralConfig & gc)
 	this->file_path = gc.scheme_dir + "/" + file_name;
 
 	/* Initialise with general configurations ************** */
-	CPU_IDLE_LIMIT = gc.CPU_IDLE_LIMIT;
 	MAX_CPUS_ONLINE = gc.MAX_CPUS_ONLINE;
 	CPU_IDLE_TIMEOUT = gc.CPU_IDLE_TIMEOUT;
-	CPU_HIGH_LIMIT = gc.CPU_HIGH_LIMIT;
-	JUMP_CPU_FREQ_MAX_LIMIT = gc.JUMP_CPU_FREQ_MAX_LIMIT;
 	CPUFREQ_ENABLED = gc.CPUFREQ_ENABLED;
-	CPUFREQ_HYSTERESIS = gc.CPUFREQ_HYSTERESIS;
+	CPUFREQ_DYNAMIC_PERFORMANCE = gc.CPUFREQ_DYNAMIC_PERFORMANCE;
 	CONSIDER_NICE = gc.CONSIDER_NICE;
 	POLL_INTERVAL = gc.POLL_INTERVAL;
 
@@ -53,10 +50,6 @@ SchemeConfig::SchemeConfig(const string &file_name, const GeneralConfig & gc)
 
 	DISPLAY_BRIGHTNESS = gc.DISPLAY_BRIGHTNESS;
 
-	USER_STANDBY_DISABLED = gc.USER_STANDBY_DISABLED;
-	USER_SUSPEND2DISK_DISABLED = gc.USER_SUSPEND2DISK_DISABLED;
-	USER_SUSPEND2RAM_DISABLED = gc.USER_SUSPEND2RAM_DISABLED;
-	DPM_ENABLED = gc.DPM_ENABLED;
 	POWER_BUTTON_DELAY = gc.POWER_BUTTON_DELAY;
 
 	ALLOW_THROTTLING = gc.ALLOW_THROTTLING;
@@ -68,8 +61,6 @@ SchemeConfig::SchemeConfig(const string &file_name, const GeneralConfig & gc)
 	SCHEME_DESCRIPTION = gc.SCHEME_DESCRIPTION;
 	CPUFREQ_CONTROL = gc.CPUFREQ_CONTROL;
 
-	dpmClasses = gc.dpmClasses;
-
 	eventMap = gc.eventMap;
 	next = NULL;
 
@@ -119,7 +110,7 @@ ostream & operator<<(ostream & os, SchemeConfig & sc)
 			cpufreq_st = "invalid value";
 	}
 
-	switch (sc.ENABLE_THERMAL_MANAGEMENT == OFF){
+	switch (sc.ENABLE_THERMAL_MANAGEMENT){
 		case OFF:
 			thermal_management = "off";
 			break;
@@ -140,11 +131,6 @@ ostream & operator<<(ostream & os, SchemeConfig & sc)
 		os << i->first << "\t" << i->second << endl;
 
 	os << endl << "CPU settings:"
-	    << endl << "CPU_IDLE_LIMIT: " << sc.CPU_IDLE_LIMIT << "%"
-	    << endl << "CPU_IDLE_TIMEOUT: " << sc.CPU_IDLE_TIMEOUT
-	    << endl << "CPU_HIGH_LIMIT: " << sc.CPU_HIGH_LIMIT << "%"
-	    << endl << "JUMP_CPU_FREQ_MAX_LIMIT: " << sc.JUMP_CPU_FREQ_MAX_LIMIT << "%"
-	    << endl << "CPUFREQ_HYSTERESIS: " << sc.CPUFREQ_HYSTERESIS << "%"
 	    << endl << "CONSIDER_NICE: " << (sc.CONSIDER_NICE == 1 ? "yes" : "no")
 	    << endl << "POLL_INTERVAL: " << sc.POLL_INTERVAL
 	    << endl << endl << "Battery settings:"
@@ -154,11 +140,6 @@ ostream & operator<<(ostream & os, SchemeConfig & sc)
 	    << endl << "FORCE_BATTERY_POLLING: " << (sc.FORCE_BATTERY_POLLING == 1 ? "yes" : "no")
 	    << endl << endl << "Temperature settings:"
 	    << endl << "POWERSAVE_ENABLE_THERMAL_MANAGEMENT: " << thermal_management
-	    << endl << endl << "Other settings:" << endl << "USER_SUSPEND2DISK_DISABLED: " << (sc.
-											       USER_SUSPEND2DISK_DISABLED
-											       == 1 ? "yes" : "no")
-	    << endl << "USER_SUSPEND2RAM_DISABLED: " << (sc.USER_SUSPEND2RAM_DISABLED == 1 ? "yes" : "no")
-	    << endl << "USER_STANDBY_DISABLED: " << (sc.USER_STANDBY_DISABLED == 1 ? "yes" : "no")
 	    << endl << "CONSIDER_NICE: " << (sc.CONSIDER_NICE ? "yes" : "no")
 	    << endl << "POWER_BUTTON_DELAY: " << sc.POWER_BUTTON_DELAY;
 
