@@ -40,7 +40,7 @@
 
 static int isACPI = NOT_SUPPORTED;
 
-int checkACPI()
+int checkACPI(void)
 {
 	/* already set, so don't check it again */
 	if (isACPI != NOT_SUPPORTED)
@@ -58,39 +58,6 @@ int checkACPI()
 	}
 }
 
-#ifdef NOTING
-/* ToDo: find a good solution for one time initialisation*/
-/* of sysfs*/
-
-/* do we have a sysfs running system?*/
-/* this is mainly needed for cpufreq*/
-int isSYSFS()
-{
-	/* check SYSFS static variable so that I have to check this only once! */
-	struct utsname un;
-	/* not initialised yet */
-	if (SYSFS == UNKNOWN) {
-		uname(&un);
-		if (!strncmp(un.release, "2.4", 3)) {
-			SYSFS = 0;
-			MIN_SPEED_FILE = PROC_MIN_SPEED_FILE;
-			MAX_SPEED_FILE = PROC_MAX_SPEED_FILE;
-			CURRENT_SPEED_FILE = PROC_CURRENT_SPEED_FILE;
-			GOVERNOR_FILE = PROC_GOVERNOR_FILE;
-			USERSPACE = PROC_USERSPACE;
-		} else {
-			SYSFS = 1;
-			MIN_SPEED_FILE = SYSFS_MIN_SPEED_FILE;
-			MAX_SPEED_FILE = SYSFS_MAX_SPEED_FILE;
-			CURRENT_SPEED_FILE = SYSFS_CURRENT_SPEED_FILE;
-			GOVERNOR_FILE = SYSFS_GOVERNOR_FILE;
-			USERSPACE = SYSFS_USERSPACE;
-		}
-	}
-	return SYSFS;
-}
-#endif
-
 int getDevicesNum(const char *dir_name)
 {
 	DIR *dir;
@@ -217,11 +184,13 @@ int getDirEntry(const int num, char *file, const size_t size_file, const char *d
 int _write_line(const char *filename, const char *fmt, ...)
 {
 	FILE *fp = fopen(filename, "w+");
+	va_list ap;
+	
 	if (!fp) {
 		pDebug(DBG_DIAG, "Could not open %s for writing", filename);
 		return -1;
 	}
-	va_list ap;
+
 	va_start(ap, fmt);	/* get variable argument list passed */
 	if (vfprintf(fp, fmt, ap) < 0) {
 		pDebug(DBG_DIAG, "Could not write to %s", filename);
@@ -233,45 +202,6 @@ int _write_line(const char *filename, const char *fmt, ...)
 	return 1;
 }
 
-int read_apm_info(apm_info * i)
-{
-	FILE *str;
-	char units[10] = "";
-	char buffer[100] = "";
-	int retcode = 1;
-
-	if (!(str = fopen(APM_PROC, "r")))
-		return -1;
-
-	if (fgets(buffer, sizeof(buffer) - 1, str) == NULL) {
-		pDebug(DBG_ERR,"Error fgets()");
-		return -2;
-	}
-
-	buffer[sizeof(buffer) - 1] = '\0';
-
-	/* Should check for other driver versions; driver 1.9 (and some
-	 * others) uses this format, which doesn't expose # batteries.
-	 */
-	sscanf(buffer, "%s %d.%d %x %x %x %x %d%% %d %s\n",
-	       (char *)i->driver_version,
-	       &i->apm_version_major,
-	       &i->apm_version_minor,
-	       &i->apm_flags,
-	       &i->ac_line_status,
-	       &i->battery_status, &i->battery_flags, &i->battery_percentage, &i->battery_time, units);
-	i->using_minutes = !strncmp(units, "min", 3) ? 1 : 0;
-	if (i->driver_version[0] == 'B') {	/* old style.  argh. */
-		retcode = -2;
-	}
-
-	if (i->battery_percentage > 100)
-		i->battery_percentage = -1;
-
-	fclose(str);
-	return retcode;
-}
-
 inline int check_ACPI_dir(const char *directory)
 {
 
@@ -302,3 +232,18 @@ inline int check_ACPI_dir(const char *directory)
 		return NO_DEVICE_ERROR;
 }
 
+
+char *DBus_Error_Array[REPLY_ERROR_MAX] = {
+	"success",
+	"no connection",
+	"no rights",
+	"invalid param",
+	"invalid method",
+	"invalid interface",
+	"not supported",
+	"disabled",
+	"already set",
+	"dbus error",
+	"general error",
+	"dbus invalid message type",
+};
