@@ -46,6 +46,12 @@ extern "C" {
  * @{ 
  */
 
+/* dbus related defines */
+#define PS_DBUS_SERVICE			"com.novell.powersave"
+#define PS_DBUS_INTERFACE		"com.novell.powersave"
+#define PS_DBUS_SCRIPTS_INTERFACE	"com.novell.powersave.scripts"
+#define PS_DBUS_PATH			"/com/novell/powersave"
+
 /** @brief maximum length of a filepath
  *
  * Hope this is only under /proc/acpi where this is correct.
@@ -55,12 +61,6 @@ extern "C" {
 /** @brief maximum length of a line */
 #define MAX_LINE_SIZE 1024
 
-/** @brief maximum number of batteries we support */
-#define MAX_BATTERIES 4
-
-/** @brief Max string length in ACPI Source Language: 200 bytes */
-#define MAX_BAT_CHAR_LEN 200
-
 #define MAX_THERMAL_ACTIVE 10
 
 /** @brief error if acpi is not supported by the system */
@@ -90,23 +90,6 @@ extern "C" {
 /** @brief defines whether charging or discharging */
 #define CHARG_STATE_CHARG_DISCHARG (CHARG_STATE_CHARGING | CHARG_STATE_DISCHARGING)
 
-/** @brief acpi sleep state S1 */
-#define ACPI_S1 1
-/** @brief acpi sleep state S2 */
-#define ACPI_S2 2
-/** @brief acpi sleep state S3 */
-#define ACPI_S3 4
-/** @brief acpi sleep state S3 bios */
-#define ACPI_S3_BIOS 8
-/** @brief acpi sleep state S4 */
-#define ACPI_S4 16
-/** @brief acpi sleep state S4 bios */
-#define ACPI_S4_BIOS 32
-/** @brief apm standby */
-#define APM_STANDBY 64
-/** @brief apm suspend */
-#define APM_SUSPEND 128
-
 /* debugging macros and defines */
 #ifdef POWERSAVE_DEBUG
 #define DBG_ERR 1
@@ -161,30 +144,9 @@ do{\
 #define pDebug(level, string, args...) do {} while (0);
 #endif /* POWERSAVE_DEBUG */
 	
-	/** @brief whether the battery is present */
-	enum BATTERY_PRESENT { PRESENT_YES = 0, PRESENT_NO };
-	
-	/** @brief the unit of the battery capacity */
-	enum CAPACITY_UNIT { WATT_H = 0, AMP };
-	
-	/** @brief technologie of the battery */
-	enum BATTERY_TECH { TECH_NON_RECHARGEABLE = 0, TECH_RECHARGEABLE };
-	
-	/** because of kernel implementations separated in ACPI spec this
-	 * is combined to battery_state 
-	 * be careful this is kernel definition of batteries states !
-	 */
-	enum CAPACITY_STATE { STATE_OK, STATE_CRIT, STATE_LOW, STATE_WARN };
-
 	/** @brief ac adapter status */
 	enum AC_ADAPTER_STATE { AC_UNKNOWN, AC_ONLINE, AC_OFFLINE };
 	
-	/** @brief states a disk can be in */
-	enum DISK_MODE { DISK_FULL_ON, DISK_STANDBY, DISK_SLEEP };
-
-	/** @brief current state of the lid */
-	enum LID_STATE { LID_OPEN, LID_CLOSED };
-
 	/** @brief use for checkACPI function return value! */
 	enum ISACPI { NOT_SUPPORTED = -1, APM, ACPI };
 
@@ -217,40 +179,6 @@ do{\
 		int charging_state;
 	} BatteryGeneral;
 	
-	/** @brief Detailed battery information
-	 *
-	 * only available for ACPI through the getBatteryDetailedInfo function
-	 */
-	typedef struct BatteryDetailed {
-		/** @brief whether battery is currently present */
-		int present;
-		
-		/* from /proc/acpi/battery/ /info */
-		int design_capacity;
-		int last_full_capacity;
-		int battery_technology;
-		int design_voltage;
-		int design_capacity_warning;
-		int design_capacity_low;
-		int capacity_granularity_1;
-		int capacity_granularity_2;
-		char model_number[MAX_BAT_CHAR_LEN + 1];
-		char serial_number[MAX_BAT_CHAR_LEN + 1];
-		char battery_type[MAX_BAT_CHAR_LEN + 1];
-		char OEM_info[MAX_BAT_CHAR_LEN + 1];
-		
-		/* from /proc/acpi/battery/ /status */
-		int power_unit;
-		int capacity_state;
-		int charging_state;
-		int present_rate;
-		int remaining_capacity;
-		int present_voltage;
-		
-		/* from /proc/acpi/battery/ /alarm */
-		int alarm_limit;
-	} BatteryDetailed;
-
 	/** @brief object representing a thermal device */
 	typedef struct ThermalDev {
 		int present;
@@ -268,7 +196,27 @@ do{\
 		int tc2;
 		int tsp;
 	} ThermalDev;
-	
+
+	/** @brief dbus error message ids the daemon may send. They can be
+	 *         mapped to the DBus_Error_Array string array below
+	 */
+	enum DBUS_ERROR { REPLY_SUCCESS,
+		REPLY_NO_CONNECTION,
+		REPLY_NO_RIGHTS,
+		REPLY_INVALID_PARAM,
+		REPLY_INVALID_METHOD,
+		REPLY_INVALID_INTERFACE,
+		REPLY_HW_NOT_SUPPORTED,
+		REPLY_DISABLED,
+		REPLY_ALREADY_SET,
+		REPLY_DBUS_ERROR,
+		REPLY_GENERAL_ERROR,
+		REPLY_INVALID_MESSAGE_TYPE,
+		REPLY_ERROR_MAX
+	};
+
+	extern char *DBus_Error_Array[REPLY_ERROR_MAX];
+
 	/** @brief fills the given Battery struct with the current battery
 	 *  information for all primary batteries
 	 *
@@ -282,58 +230,12 @@ do{\
 	 */
 	int getBatteriesInfo(BatteryGeneral * bat);
 
-	/** @brief get Information for only one primary battery
-	 *
-	 * this function only returns values for primary batteries
-	 *
-	 * @param no number of primary battery to query starting from 0
-	 * @param battery_info pointer to an @ref BatteryGeneral struct
-	 * @retval 1 on success and battery is present
-	 * @retval 0 on success but battery is not present
-	 * @retval < 0 on error
-	 */
-	int getBatteryInfo(const int no, BatteryGeneral *battery_info);
-
-	/** @brief get number of present primary batteries
-	 *
-	 * @return number of primary batteries (also not present ones) or
-	 *         -1 on error
-	 */
-	int numBatteries(void);
-
-	/** @brief use this method to get detailed information about a
-	 *         primary battery
-	 *
-	 * <b>ACPI only!</b>
-	 *
-	 * @param no battery number
-	 * @param bd pointer to detailed battery info structure
-	 *
-	 * @return: integer with result of call
-	 * @retval 0 SUCCESS
-	 * @retval < 0 ERROR
-	 * @retval -1 general error
-	 * @retval -2 if device no does not exist
-	 * @retval -3 if struct has not initialized with memory
-	 * @retval NO_ACPI_ERROR if it is not an ACPI system 
-	 * @retval NO_MODULE_ERROR if the battery module is not loaded 
-	 * @retval NO_DEVICE_ERROR if there is a fan directory, but no device 
-	 * @retval > 0 END OF BATTERIES REACHED
-	 */
-	int getBatteryDetailedInfo(const int no, BatteryDetailed * bd);
-
 	/** @brief sets the ACPI battery alarm for all batteries
 	 *
 	 * <b>ACPI only!</b><br>
 	 */
 	int setBatteryAlarm(const int percent);
 
-	/** @brief returns the current state of the lid
-	 *
-	 * @return @ref LID_STATE
-	 */
-	int getLidState(void);
-
 	/** @brief get throttling information (ACPI only)
 	 *
  	 * <b>ACPI only!</b>
@@ -558,20 +460,6 @@ do{\
 	 */
 	void freeCPULoadData(void);
 
-	/** @brief get number of cpus in system
-	 *
-	 * @return number of cpus, < 0 on error
-	 */
-	int getCPUCount(void);
-
-	/** @brief get all supported sleeping states
-	 *
-	 * mask out return value to evaluate supported states
-	 *
-	 * @retval 0 if no support
-	 */
-	int64_t getSupportedSleepStates(void);
-
 	/** @brief determine whether there is apm, acpi or nothing on your Computer
 	 *
 	 * @return integer values representing acpi status
