@@ -7,6 +7,9 @@
 #     POWERSAVE_EVENT_PROCESSOR_DYNAMIC_HIGH => EVENT_PROCESSOR_BUSY
 #     POWERSAVE_EVENT_PROCESSOR_DYNAMIC_LOW  => EVENT_PROCESSOR_IDLE
 #     POWERSAVED_DYNAMIC_LOW_CPU_LIMIT       => PROCESSOR_IDLE_LIMIT
+#
+# also sets the ACPI_MODULES.*-variables to an empty string "" since
+# the defaults on those should make much more sense now.
 
 PSCONF=/etc/sysconfig/powersave
 BACKUP=$PSCONF/.backup_pre-0.10 # must start with a dot.
@@ -25,7 +28,7 @@ fi
 
 if [ -e $BACKUP ]; then
     # we already ran but did not update correctly. Should not happen.
-    echo "directory /etc/sysconfig/powersave/backup_pre_0.10 already exists"
+    echo "directory /etc/sysconfig/powersave/.backup_pre_0.10 already exists"
     DIR=`mktemp -d ${BACKUP}_XXXXXX`
     if [ -z "$DIR" ]; then
         echo "could not create tempdir for backup of config"
@@ -43,5 +46,6 @@ for i in *; do
     sed 's/POWERSAVED\?_//;
          s/EVENT_PROCESSOR_DYNAMIC_HIGH/EVENT_PROCESSOR_BUSY/;
          s/EVENT_PROCESSOR_DYNAMIC_LOW/EVENT_PROCESSOR_IDLE/;
-         s/DYNAMIC_LOW_CPU_LIMIT/PROCESSOR_IDLE_LIMIT/' $i > $PSCONF/$i
+         s/DYNAMIC_LOW_CPU_LIMIT/PROCESSOR_IDLE_LIMIT/;
+         s/^\(ACPI_MODULES\(\|_NOT_TO_UNLOAD\)\)="..*"$/\1=""/' $i > $PSCONF/$i
 done
